@@ -1,6 +1,6 @@
 package Mason::Plugin::RouterSimple::Interp;
 BEGIN {
-  $Mason::Plugin::RouterSimple::Interp::VERSION = '0.06';
+  $Mason::Plugin::RouterSimple::Interp::VERSION = '0.07';
 }
 use Mason::PluginRole;
 use Mason::Util qw(uniq);
@@ -11,7 +11,8 @@ after 'modify_loaded_class' => sub {
 
     if ( my $router_object = $compc->router_object ) {
         my $routes = $router_object->{routes};
-        my @attrs = uniq( map { @{ $_->{capture} } } @$routes );
+        my @attrs =
+          uniq( map { @{ $_->{capture} }, $_->{dest} ? keys( %{ $_->{dest} } ) : () } @$routes );
         for (@attrs) { s/__splat__/splat/ }
         my $meta = $compc->meta;
         foreach my $attr (@attrs) {
