@@ -1,12 +1,12 @@
 package Mason::Plugin::RouterSimple::t::Basic;
 BEGIN {
-  $Mason::Plugin::RouterSimple::t::Basic::VERSION = '0.06';
+  $Mason::Plugin::RouterSimple::t::Basic::VERSION = '0.07';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
 __PACKAGE__->default_plugins( [ '@Default', 'RouterSimple' ] );
 
-sub test_ok : Tests() {
+sub test_routes : Tests {
     my $self = shift;
 
     $self->add_comp(
@@ -24,6 +24,7 @@ $.page => (default => "standard")
 month = <% $.month || "undef" %>
 page = <% $.page || "standard" %>
 splat = <% $.splat ? split(",", $.splat) : "undef" %>
+action = <% $.action || "undef" %>
 
 % $m->result->data->{args} = $.args;
 ',
@@ -37,9 +38,10 @@ splat = <% $.splat ? split(",", $.splat) : "undef" %>
             my $month = $expect->{month} || "undef";
             my $page  = $expect->{page}  || "standard";
             my $splat = $expect->{splat} ? split( ',', $expect->{splat} ) : "undef";
+            my $action = $expect->{action} || "undef";
             $self->test_comp(
                 path        => $path,
-                expect      => "month = $month\npage = $page\nsplat = $splat",
+                expect      => "month = $month\npage = $page\nsplat = $splat\naction = $action",
                 expect_data => { args => { %$expect, router_result => $expect } },
             );
         }
@@ -54,10 +56,28 @@ splat = <% $.splat ? split(",", $.splat) : "undef" %>
     $try->( '/foo/blog/2010/02', { year => '2010', month => '02' } );
     $try->( '/foo/baz',          undef );
     $try->( '/foo/blog/201O/02', undef );
+}
 
-    # It's ok not to have routes
-    #
-    $self->test_comp( src => '2+2=<% 2+2 %>', expect => '2+2=4' );
+sub test_no_routes : Tests {
+    my $self = shift;
+
+    $self->add_comp(
+        path => '/no_route.mc',
+        src  => '<%class>method allow_path_info { 1 }</%class>
+path_info = <% $m->path_info || "" %>',
+    );
+    $self->test_existing_comp( path => '/no_route',     expect => 'path_info =' );
+    $self->test_existing_comp( path => '/no_route/abc', expect => 'path_info = abc' );
+
+    $self->add_comp(
+        path => '/no_route_or_allow.mc',
+        src  => 'path_info = <% $m->path_info || "" %>',
+    );
+    $self->test_existing_comp( path => '/no_route_or_allow', expect => 'path_info =' );
+    $self->test_existing_comp(
+        path         => '/no_route_or_allow/abc',
+        expect_error => qr/could not resolve request path/
+    );
 }
 
 1;
